Module commitment

Module commitment 

Functions

commit
Cryptographically commits to a position before revealing it. Uses BLAKE3 under the hood.
commit_response
Cryptographically commits to the structured response evidence before reveal.
verify_commitment
Verifies that a revealed position matches its prior commitment.
verify_response_commitment
Verifies that revealed structured response evidence matches its commitment.