pub fn commit_response(response: &ModelDeliberationResponse) -> Result<Hash256>Expand description
Cryptographically commits to the structured response evidence before reveal.
pub fn commit_response(response: &ModelDeliberationResponse) -> Result<Hash256>Cryptographically commits to the structured response evidence before reveal.