pub struct DeliberationSession {
pub session_id: String,
pub panel: Panel,
pub question: String,
pub current_round: u32,
pub rounds: Vec<DeliberationRound>,
pub response_provider: DeterministicResponseProvider,
}Fields
session_id: Stringpanel: Panelquestion: Stringcurrent_round: u32rounds: Vec<DeliberationRound>response_provider: DeterministicResponseProviderImplementations
Sourceimpl DeliberationSession
impl DeliberationSession
pub fn new( session_id: String, panel: Panel, question: String, response_provider: DeterministicResponseProvider, ) -> Self
pub fn execute_round( &mut self, timing: RoundExecutionTiming, ) -> Result<DeliberationRound>
pub fn is_converged(&self) -> bool
Sourcepub fn finalize(self, timing: FinalizationTiming) -> Result<DeliberationResult>
pub fn finalize(self, timing: FinalizationTiming) -> Result<DeliberationResult>
Finalize the session, consuming it so the full round history moves into the result without duplicating consensus evidence in memory.