Functions
- commit
- Cryptographically commits to a position before revealing it. Uses BLAKE3 under the hood.
- commit_
response - Cryptographically commits to the structured response evidence before reveal.
- verify_
commitment - Verifies that a revealed position matches its prior commitment.
- verify_
response_ commitment - Verifies that revealed structured response evidence matches its commitment.